@@ -150,23 +150,25 @@ long MessageBox::onCmdSu(FXObject*, FXSelector sel, void*)
     FXbool use_sudo = getApp()->reg().readUnsignedEntry("OPTIONS", "use_sudo", FALSE);
 
     // Use sudo or su to launch xfe as root
-    FXString title, sucmd, command;
+    FXString title, cmd, command;
     if (use_sudo)
     {
         title = _("Enter the user password:");
-        sucmd = SUDOCMD;
+	    FXString sudo_cmd = getApp()->reg().readStringEntry("OPTIONS", "sudo_cmd", DEFAULT_SUDO_CMD);
+        cmd = " -g 60x4 -e " + sudo_cmd;
     }
     else
     {
         title = _("Enter the root password:");
-        sucmd = SUCMD;
+     	FXString su_cmd = getApp()->reg().readStringEntry("OPTIONS", "su_cmd", DEFAULT_SU_CMD);
+        cmd = " -g 60x4 -e " + su_cmd;
     }
 
     // Get text font
     FXString fontspec = getApp()->reg().readStringEntry("SETTINGS", "textfont", DEFAULT_TEXT_FONT);
     if (fontspec.empty())
     {
-		command = "st -t " + ::quote(title) + sucmd;
+		command = "st -t " + ::quote(title) + cmd;
 	}
 	else
 	{
@@ -174,7 +176,7 @@ long MessageBox::onCmdSu(FXObject*, FXSelector sel, void*)
         FXFont* font = new FXFont(getApp(), fontspec);
         font->create();
 		snprintf(fontsize, sizeof(fontsize), "%d",(int)(font->getSize()/10)); // Size is in deci-points, thus divide by 10
-		command = "st -t " + ::quote(title) + " -f '" + (font->getFamily()).text() + ":pixelsize=" + fontsize + "'" + sucmd;
+		command = "st -t " + ::quote(title) + " -f '" + (font->getFamily()).text() + ":pixelsize=" + fontsize + "'" + cmd;
     }
 
     // Execute su or sudo command in an internal st terminal
