@@ -117,6 +117,7 @@ FXDEFMAP(PreferencesBox) PreferencesMap[] =
     FXMAPFUNC(SEL_UPDATE, PreferencesBox::ID_WHEELADJUST, PreferencesBox::onUpdWheelAdjust),
     FXMAPFUNC(SEL_UPDATE, PreferencesBox::ID_SCROLLBARSIZE, PreferencesBox::onUpdScrollBarSize),
     FXMAPFUNC(SEL_UPDATE, PreferencesBox::ID_SINGLE_CLICK_FILEOPEN, PreferencesBox::onUpdSingleClickFileopen),
+    FXMAPFUNC(SEL_UPDATE, PreferencesBox::ID_EXEC_TEXT_FILES, PreferencesBox::onUpdExecTextFiles),
     FXMAPFUNC(SEL_UPDATE, PreferencesBox::ID_CONFIRM_TRASH, PreferencesBox::onUpdTrash),
     FXMAPFUNC(SEL_UPDATE, PreferencesBox::ID_TRASH_BYPASS, PreferencesBox::onUpdTrash),
     FXMAPFUNC(SEL_UPDATE, PreferencesBox::ID_CONFIRM_DEL_EMPTYDIR, PreferencesBox::onUpdConfirmDelEmptyDir),
@@ -192,6 +193,7 @@ PreferencesBox::PreferencesBox(FXWindow* win, FXColor listbackcolor, FXColor lis
 #ifdef STARTUP_NOTIFICATION
     usesn = new FXCheckButton(group, _("Notify when applications start up"));
 #endif
+    noscript = new FXCheckButton(group, _("Don't execute text files"));
 
     FXMatrix* matrix = new FXMatrix(group, 2, MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     new FXLabel(matrix, _("Date format used in file and folder lists:\n(Type 'man strftime' in a terminal for help on the format)"), NULL, JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
@@ -199,6 +201,7 @@ PreferencesBox::PreferencesBox(FXWindow* win, FXColor listbackcolor, FXColor lis
     oldtimeformat = getApp()->reg().readStringEntry("SETTINGS", "time_format", DEFAULT_TIME_FORMAT);
     timeformat->setText(oldtimeformat);
 
+    // Second tab - Modes
     new FXTabItem(tabbook, _("&Modes"), NULL);
     FXVerticalFrame* modes = new FXVerticalFrame(tabbook, FRAME_RAISED);
 
@@ -225,21 +228,41 @@ PreferencesBox::PreferencesBox(FXWindow* win, FXColor listbackcolor, FXColor lis
     spinner = new FXSpinner(matrix, 3, this, PreferencesBox::ID_SCROLLBARSIZE, JUSTIFY_RIGHT|LAYOUT_FILL_X|LAYOUT_FILL_ROW, 0, 0, 0, 0, 2, 2, 1, 1);
     spinner->setRange(1, 100);
 
-    group = new FXGroupBox(modes, _("Root mode"), GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
-    rootmode = new FXCheckButton(group, _("Allow root mode"));
-    FXRadioButton* subutton = new FXRadioButton(group, _("Authentication using su (uses root password)"), this, ID_SU_CMD);
-    FXRadioButton* sudobutton = new FXRadioButton(group, _("Authentication using sudo (uses user password)"), this, ID_SUDO_CMD);
+    rootgroup = new FXGroupBox(modes, _("Root mode"), GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+    rootmode = new FXCheckButton(rootgroup, _("Allow root mode"));
+    FXRadioButton* sudobutton = new FXRadioButton(rootgroup, _("Authentication using sudo (uses user password)"), this, ID_SUDO_CMD);
+    FXRadioButton* subutton = new FXRadioButton(rootgroup, _("Authentication using su (uses root password)"), this, ID_SU_CMD);
+
+	// Su et sudo commands
+    matrix = new FXMatrix(rootgroup, 2, MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+    sudolabel = new FXLabel(matrix, _("sudo command:"), NULL, JUSTIFY_LEFT);
+    sudocmd = new FXTextField(matrix, 40, NULL, 0, FRAME_THICK|FRAME_SUNKEN);
+    sulabel = new FXLabel(matrix, _("su command:"), NULL, JUSTIFY_LEFT);
+    sucmd = new FXTextField(matrix, 40, NULL, 0, FRAME_THICK|FRAME_SUNKEN);
+
+    FXString sudo_cmd = getApp()->reg().readStringEntry("OPTIONS", "sudo_cmd", DEFAULT_SUDO_CMD);
+    FXString su_cmd = getApp()->reg().readStringEntry("OPTIONS", "su_cmd", DEFAULT_SU_CMD);
+	sudocmd->setText(sudo_cmd);
+	sucmd->setText(su_cmd);
+	sudocmd_prev = sudo_cmd;
+	sucmd_prev = su_cmd;
 
     FXbool root_mode = getApp()->reg().readUnsignedEntry("OPTIONS", "root_mode", true);
     rootmode->setCheck(root_mode);
 
-    if (getuid() == 0) // Super user
+    // User is root
+    if (getuid() == 0)
     {
+        rootgroup->disable();
         rootmode->disable();
         subutton->disable();
         sudobutton->disable();
+        sulabel->disable();
+        sucmd->hide();
+        sudolabel->disable();
+        sudocmd->hide();
     }
-    use_sudo = getApp()->reg().readUnsignedEntry("OPTIONS", "use_sudo", false);
+    use_sudo = getApp()->reg().readUnsignedEntry("OPTIONS", "use_sudo", true);
 
     FXbool use_trash_can = getApp()->reg().readUnsignedEntry("OPTIONS", "use_trash_can", true);
     trashcan->setCheck(use_trash_can);
@@ -279,42 +302,25 @@ PreferencesBox::PreferencesBox(FXWindow* win, FXColor listbackcolor, FXColor lis
     }
 
     // File tooltips
-    if (file_tooltips == false)
-    {
-        filetooltips->setCheck(false);
-    }
-    else
-    {
-        filetooltips->setCheck(true);
-    }
+    filetooltips->setCheck(file_tooltips);
 
     // Relative resizing
-    if (relative_resize == false)
-    {
-        relativeresize->setCheck(false);
-    }
-    else
-    {
-        relativeresize->setCheck(true);
-    }
+    relativeresize->setCheck(relative_resize);
 
     // Display path linker
     show_pathlink = getApp()->reg().readUnsignedEntry("SETTINGS", "show_pathlinker", true);
-    if (show_pathlink == false)
-    {
-        showpathlink->setCheck(false);
-    }
-    else
-    {
-        showpathlink->setCheck(true);
-    }
+    showpathlink->setCheck(show_pathlink);
 
 #ifdef STARTUP_NOTIFICATION
     FXbool use_sn = getApp()->reg().readUnsignedEntry("OPTIONS", "use_startup_notification", true);
     usesn->setCheck(use_sn);
 #endif
 
-    // Second tab - Dialogs
+    // Do not run script files
+    FXbool no_script = getApp()->reg().readUnsignedEntry("OPTIONS", "no_script", false);
+    noscript->setCheck(no_script);
+
+    // Third tab - Dialogs
     new FXTabItem(tabbook, _("&Dialogs"), NULL);
     FXVerticalFrame* dialogs = new FXVerticalFrame(tabbook, FRAME_RAISED);
     group = new FXGroupBox(dialogs, _("Confirmations"), GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
@@ -324,7 +330,7 @@ PreferencesBox::PreferencesBox(FXWindow* win, FXColor listbackcolor, FXColor lis
     del = new FXCheckButton(group, _("Confirm delete"));
     del_emptydir = new FXCheckButton(group, _("Confirm delete non empty folders"), this, ID_CONFIRM_DEL_EMPTYDIR);
     overwrite = new FXCheckButton(group, _("Confirm overwrite"));
-    exec = new FXCheckButton(group, _("Confirm execute text files"));
+    exec = new FXCheckButton(group, _("Confirm execute text files"), this, ID_EXEC_TEXT_FILES);
     properties = new FXCheckButton(group, _("Confirm change properties"));
 
     group = new FXGroupBox(dialogs, _("Warnings"), GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
@@ -367,7 +373,9 @@ PreferencesBox::PreferencesBox(FXWindow* win, FXColor listbackcolor, FXColor lis
     preserve_date_warning->setCheck(preserve_date_warn);
 
     FXbool root_warn = getApp()->reg().readUnsignedEntry("OPTIONS", "root_warn", true);
-    if (getuid()) // Simple user
+    
+    // User is non root
+    if (getuid())
     {
         root_warning->disable();
     }
@@ -376,7 +384,7 @@ PreferencesBox::PreferencesBox(FXWindow* win, FXColor listbackcolor, FXColor lis
         root_warning->setCheck(root_warn);
     }
 
-    // Third tab - Programs
+    // Fourth tab - Programs
     new FXTabItem(tabbook, _("&Programs"), NULL);
     FXVerticalFrame* programs = new FXVerticalFrame(tabbook, FRAME_RAISED);
     group = new FXGroupBox(programs, _("Default programs"), GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
@@ -458,7 +466,7 @@ PreferencesBox::PreferencesBox(FXWindow* win, FXColor listbackcolor, FXColor lis
     umountcmd->setText(oldumountcmd);
 
 
-    // Fourth tab - Visual
+    // Fifth tab - Visual
     new FXTabItem(tabbook, _("&Themes"), NULL);
     FXVerticalFrame* visual = new FXVerticalFrame(tabbook, FRAME_RAISED);
     FXGroupBox*      themes = new FXGroupBox(visual, _("Color theme"), GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
@@ -506,7 +514,7 @@ PreferencesBox::PreferencesBox(FXWindow* win, FXColor listbackcolor, FXColor lis
     oldiconpath = getApp()->reg().readStringEntry("SETTINGS", "iconpath", DEFAULTICONPATH);
     iconpath->setText(oldiconpath);
 
-    // Fifth tab - Fonts
+    // Sixth tab - Fonts
     new FXTabItem(tabbook, _("&Fonts"), NULL);
     FXVerticalFrame* fonts = new FXVerticalFrame(tabbook, FRAME_RAISED);
     FXGroupBox*      fgroup = new FXGroupBox(fonts, _("Fonts"), GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
@@ -524,7 +532,7 @@ PreferencesBox::PreferencesBox(FXWindow* win, FXColor listbackcolor, FXColor lis
     oldtextfont = getApp()->reg().readStringEntry("SETTINGS", "textfont", DEFAULT_TEXT_FONT);
     textfont->setText(oldtextfont);
 
-    // Sixth tab - Key bindings
+    // Seventh tab - Key bindings
     new FXTabItem(tabbook, _("&Key Bindings"), NULL);
     FXVerticalFrame* keybindings = new FXVerticalFrame(tabbook, FRAME_RAISED);
     FXGroupBox*      kbgroup = new FXGroupBox(keybindings, _("Key Bindings"), GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
@@ -567,6 +575,7 @@ PreferencesBox::PreferencesBox(FXWindow* win, FXColor listbackcolor, FXColor lis
 #ifdef STARTUP_NOTIFICATION
     usesn_prev = false;
 #endif
+    noscript_prev = false;
 #if defined(linux)
     mount_prev = false;
     show_mount_prev = false;
@@ -1693,9 +1702,12 @@ long PreferencesBox::onCmdAccept(FXObject* o, FXSelector s, void* p)
     getApp()->reg().writeUnsignedEntry("OPTIONS", "startdir_mode", startdirmode-ID_START_HOMEDIR);
     getApp()->reg().writeUnsignedEntry("OPTIONS", "root_warn", root_warning->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS", "root_mode", rootmode->getCheck());
+    getApp()->reg().writeStringEntry("OPTIONS", "sudo_cmd", sudocmd->getText().text());
+    getApp()->reg().writeStringEntry("OPTIONS", "su_cmd", sucmd->getText().text());
 #ifdef STARTUP_NOTIFICATION
     getApp()->reg().writeUnsignedEntry("OPTIONS", "use_startup_notification", usesn->getCheck());
 #endif
+    getApp()->reg().writeUnsignedEntry("OPTIONS", "no_script", noscript->getCheck());
 #if defined(linux)
     getApp()->reg().writeUnsignedEntry("OPTIONS", "mount_warn", mount->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS", "mount_messages", show_mount->getCheck());
@@ -1856,7 +1868,7 @@ long PreferencesBox::onCmdCancel(FXObject* o, FXSelector s, void* p)
 {
     // Reset preferences to their previous values
 
-    // First tab - Options
+    // First tab - General options
     trashcan->setCheck(trashcan_prev);
     trashbypass->setCheck(trashbypass_prev);
     autosave->setCheck(autosave_prev);
@@ -1866,20 +1878,24 @@ long PreferencesBox::onCmdCancel(FXObject* o, FXSelector s, void* p)
     filetooltips->setCheck(filetooltips_prev);
     relativeresize->setCheck(relativeresize_prev);
     showpathlink->setCheck(show_pathlink_prev);
-    getApp()->setWheelLines(wheellines_prev);
-    getApp()->setScrollBarSize(scrollbarsize_prev);
-    use_sudo = use_sudo_prev;
-    getApp()->reg().writeUnsignedEntry("OPTIONS", "use_sudo", use_sudo);
-    scroll->setCheck(smoothscroll_prev);
-    rootmode->setCheck(rootmode_prev);
-    timeformat->setText(oldtimeformat);
-    startdirmode = oldstartdirmode;
-
 #ifdef STARTUP_NOTIFICATION
     usesn->setCheck(usesn_prev);
 #endif
+    noscript->setCheck(noscript_prev);
+    timeformat->setText(oldtimeformat);
 
-    // Second tab - Dialogs
+    // Second tab - Modes
+    startdirmode = oldstartdirmode;
+    scroll->setCheck(smoothscroll_prev);
+    getApp()->setWheelLines(wheellines_prev);
+    getApp()->setScrollBarSize(scrollbarsize_prev);
+    rootmode->setCheck(rootmode_prev);
+    use_sudo = use_sudo_prev;
+    getApp()->reg().writeUnsignedEntry("OPTIONS", "use_sudo", use_sudo);
+    sudocmd->setText(sudocmd_prev);
+    sucmd->setText(sucmd_prev);
+
+    // Third tab - Dialogs
     ask->setCheck(ask_prev);
     dnd->setCheck(dnd_prev);
     trashmv->setCheck(trashmv_prev);
@@ -1896,7 +1912,7 @@ long PreferencesBox::onCmdCancel(FXObject* o, FXSelector s, void* p)
     preserve_date_warning->setCheck(preserve_date_warning_prev);
     root_warning->setCheck(root_warning_prev);
 
-    // Third tab - Programs
+    // Fourth tab - Programs
     txtviewer->setText(oldtxtviewer);
     txteditor->setText(oldtxteditor);
     filecomparator->setText(oldfilecomparator);
@@ -1910,14 +1926,14 @@ long PreferencesBox::onCmdCancel(FXObject* o, FXSelector s, void* p)
     mountcmd->setText(oldmountcmd);
     umountcmd->setText(oldumountcmd);
 
-    // Fourth tab - Visual
+    // Fifth tab - Visual
     themesList->setCurrentItem(themelist_prev);
     currTheme = currTheme_prev;
     iconpath->setText(oldiconpath);
     use_clearlooks = use_clearlooks_prev;
     getApp()->reg().writeUnsignedEntry("SETTINGS", "use_clearlooks", use_clearlooks);
 
-    // Fifth tab - Fonts
+    // Sixth tab - Fonts
     normalfont->setText(oldnormalfont);
     textfont->setText(oldtextfont);
 
@@ -1944,16 +1960,21 @@ FXuint PreferencesBox::execute(FXuint placement)
     filetooltips_prev = filetooltips->getCheck();
     relativeresize_prev = relativeresize->getCheck();
     show_pathlink_prev = showpathlink->getCheck();
+#ifdef STARTUP_NOTIFICATION
+    usesn_prev = usesn->getCheck();
+#endif
+    noscript_prev = noscript->getCheck();
+
+	// Second tab - Modes
     wheellines_prev = getApp()->getWheelLines();
     scrollbarsize_prev = getApp()->getScrollBarSize();
     use_sudo_prev = use_sudo;
     smoothscroll_prev = scroll->getCheck();
     rootmode_prev = rootmode->getCheck();
-#ifdef STARTUP_NOTIFICATION
-    usesn_prev = usesn->getCheck();
-#endif
-
-    // Second tab - Dialogs
+	sudocmd_prev = sudocmd->getText();
+	sucmd_prev = sucmd->getText();
+	
+    // Third tab - Dialogs
     ask_prev = ask->getCheck();
     dnd_prev = dnd->getCheck();
     trashmv_prev = trashmv->getCheck();
@@ -1970,7 +1991,7 @@ FXuint PreferencesBox::execute(FXuint placement)
     preserve_date_warning_prev = preserve_date_warning->getCheck();
     root_warning_prev = root_warning->getCheck();
 
-    // Third tab - Programs
+    // Fourth tab - Programs
     oldtxtviewer = txtviewer->getText();
     oldtxteditor = txteditor->getText();
     oldfilecomparator = filecomparator->getText();
@@ -1984,13 +2005,13 @@ FXuint PreferencesBox::execute(FXuint placement)
     oldmountcmd = mountcmd->getText();
     oldumountcmd = umountcmd->getText();
 
-    // Fourth tab - Visual
+    // Fifth tab - Visual
     themelist_prev = themesList->getCurrentItem();
     currTheme_prev = currTheme;
     oldiconpath = iconpath->getText();
     use_clearlooks_prev = use_clearlooks;
 
-    // Fifth tab - Fonts
+    // Sixth tab - Fonts
     oldnormalfont = normalfont->getText();
     oldtextfont = textfont->getText();
 
@@ -2057,12 +2078,21 @@ long PreferencesBox::onUpdSuMode(FXObject* sender, FXSelector sel, void*)
     if (!rootmode->getCheck())
     {
         sender->handle(this, FXSEL(SEL_COMMAND, ID_DISABLE), NULL);
+        sudolabel->disable();
+        sudocmd->hide();
+        sulabel->disable();
+        sucmd->hide();
     }
     else
     {
-        if (getuid()) // Simple user
+		// Non root user
+        if (getuid())
         {
             sender->handle(this, FXSEL(SEL_COMMAND, ID_ENABLE), NULL);
+			sudolabel->enable();
+			sudocmd->show();
+			sulabel->enable();
+			sucmd->show();
         }
 
         FXSelector updatemessage = FXSEL(SEL_COMMAND, ID_UNCHECK);
@@ -2207,13 +2237,25 @@ long PreferencesBox::onUpdSingleClickFileopen(FXObject* o, FXSelector, void*)
 }
 
 
+// Update exec text files button
+long PreferencesBox::onUpdExecTextFiles(FXObject* o, FXSelector, void*)
+{
+    if (!noscript->getCheck())
+    {
+        o->handle(this, FXSEL(SEL_COMMAND, FXWindow::ID_ENABLE), NULL);
+    }
+    else
+    {
+        o->handle(this, FXSEL(SEL_COMMAND, FXWindow::ID_DISABLE), NULL);
+    }
+    return(1);
+}
+
+
 // Start directory mode
 long PreferencesBox::onCmdStartDir(FXObject*, FXSelector sel, void*)
 {
     startdirmode = FXSELID(sel);
-    //~ getApp()->reg().writeUnsignedEntry("OPTIONS","startdir_mode",startdirmode-ID_START_HOMEDIR);
-    //~ getApp()->reg().write();
-
     return(1);
 }
 
