@@ -132,7 +132,7 @@ XFilePackage::XFilePackage(FXApp* a) : FXMainWindow(a, "Xfp", NULL, NULL, DECOR_
 
     // Toolbar button: File open
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "open", "Ctrl-O");
-    new FXButton(toolbar, TAB+_("Open package file")+PARS(key), fileopenicon, this, ID_OPEN, style|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
+    new FXButton(toolbar, TAB+_("Open package file")+PARS(key), fileopenicon, this, ID_OPEN, style|FRAME_RAISED|LAYOUT_CENTER_Y|LAYOUT_LEFT);
 
     // File Menu entries
     FXMenuCommand* mc = NULL;
@@ -226,7 +226,7 @@ long XFilePackage::onCmdAbout(FXObject*, FXSelector, void*)
     msg.format(_("X File Package Version %s is a simple rpm or deb package manager.\n\n"), VERSION);
     msg += COPYRIGHT;
     MessageBox about(this, _("About X File Package"), msg.text(), xfpicon, BOX_OK|DECOR_TITLE|DECOR_BORDER,
-                     JUSTIFY_CENTER_X|ICON_BEFORE_TEXT|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+                     JUSTIFY_CENTER_X|ICON_BEFORE_TEXT|LAYOUT_CENTER_Y|LAYOUT_LEFT|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     about.execute(PLACEMENT_OWNER);
     return(1);
 }
