@@ -171,12 +171,12 @@
 #endif
 
 // Command to launch Xfe as root with sudo or su, using st as a terminal
-#ifndef SUDOCMD
-#define SUDOCMD    " -g 60x4 -e sudo su -c 'nohup xfe >& /dev/null & sleep 1'"
+#ifndef DEFAULT_SUDO_CMD
+#define DEFAULT_SUDO_CMD    "sudo su -c 'xfe &'"
 #endif
 
-#ifndef SUCMD
-#define SUCMD    " -g 60x4 -e su -c 'nohup xfe >& /dev/null & sleep 1'"
+#ifndef DEFAULT_SU_CMD
+#define DEFAULT_SU_CMD    "su -c 'xfe &'"
 #endif
 
 // Tooltips setup time and duration
