@@ -21,7 +21,7 @@
 #include "xfedefs.h"
 #include "icons.h"
 #include "xfeutils.h"
-#include "../st/st.h"
+#include "../st/x.h"
 
 
 
